@@ -238,6 +238,7 @@ QVariant DataModel::data(const QModelIndex &index, int role) const
                 else if (imageList[row]->activeState == MyImage::INACTIVE) return "Deactivated";
                 else if (imageList[row]->activeState == MyImage::BADBACK) return "Poor background model";
                 else if (imageList[row]->activeState == MyImage::BADSTATS) return "Poor data quality";
+                else if (imageList[row]->activeState == MyImage::NOASTROM) return "No astrometric solution for at least one detector";
                 else if (imageList[row]->activeState == MyImage::LOWDETECTION) return "Insufficient sources for astrometry";
                 else if (imageList[row]->activeState == MyImage::DELETED) return "Image not found or deleted";
                 else return "";
@@ -387,7 +388,7 @@ bool DataModel::setData(const QModelIndex & index, const QVariant & value, int r
             // the user clicked an unchecked box, which is now checked, hence we must activate the image
             // ONLY do this if the deactivated image has the same processing state as the active images!
             QString imagestatus = imageList[index.row()]->processingStatus->statusString;
-            QString drivestatus = imageList[index.row()]->processingStatus->whatIsStatusOnDrive();
+            QString drivestatus = myData->processingStatus->whatIsStatusOnDrive();
             if (imagestatus == drivestatus) {
                 imageList[index.row()]->oldState = imageList[index.row()]->activeState;
                 imageList[index.row()]->setActiveState(MyImage::ACTIVE); // Setting this value automatically moves the image on drive accordingly!
@@ -402,12 +403,18 @@ bool DataModel::setData(const QModelIndex & index, const QVariant & value, int r
             imageList[index.row()]->setActiveState(MyImage::INACTIVE); // Setting this value automatically moves the image on drive accordingly!
         }
         emit dataChanged(index,index);
+        emit activationChanged();    // meant to update image statistics module; has no effect
+        emit refreshMemoryViewer();
         return true;
     }
     // Force write to drive
     if (role == Qt::CheckStateRole && index.column() == 2) {
         if ((Qt::CheckState)value.toInt() == Qt::Checked) {
-            imageList[index.row()]->imageOnDrive = true;
+            MyImage *it = imageList[index.row()];
+            if (!it->imageOnDrive) {
+                it->writeImage();
+                it->imageOnDrive = true;
+            }
         }
         emit dataChanged(index,index);
         return true;
