@@ -89,6 +89,8 @@ private:
 
 signals:
     void activationWarning(QString imagestatus, QString drivestatus);
+    void refreshMemoryViewer();
+    void activationChanged();
     //    void writeImageToDisk(MyImage *myImage) const;
 };
 
