@@ -53,6 +53,7 @@ MemoryViewer::MemoryViewer(Controller *ctrl, MainWindow *parent) :
     connect(ui->procstatusCollapseCheckbox, &QCheckBox::clicked, this, &MemoryViewer::updateProcessingStatusOnDriveAndInData);
     connect(ui->procstatusStarflatCheckbox, &QCheckBox::clicked, this, &MemoryViewer::updateProcessingStatusOnDriveAndInData);
     connect(ui->procstatusSkysubCheckbox, &QCheckBox::clicked, this, &MemoryViewer::updateProcessingStatusOnDriveAndInData);
+    connect(this, &MemoryViewer::refreshMemoryViewer, mainGUI, &MainWindow::refreshMemoryViewerReceiver);
 
     QFile file(":/qss/default.qss");
     file.open(QFile::ReadOnly);
@@ -170,7 +171,9 @@ void MemoryViewer::addData(const QList<Data*> &DT_x, const QString &type)
         dataModelList.append(dataModel);
         connect(this, &MemoryViewer::beginResetModel, dataModel, &DataModel::beginResetModelReceived, Qt::DirectConnection);
         connect(this, &MemoryViewer::endResetModel, dataModel, &DataModel::endResetModelReceived, Qt::DirectConnection);
+        connect(dataModel, &DataModel::refreshMemoryViewer, mainGUI, &MainWindow::refreshMemoryViewerReceiver);
         connect(dataModel, &DataModel::activationWarning, controller, &Controller::activationWarningReceived);
+        connect(dataModel, &DataModel::activationChanged, this, &MemoryViewer::activationChangedReceiver);
     }
     if (list.isEmpty()) return;
     ui->datadirComboBox->addItems(list);
@@ -406,6 +409,8 @@ void MemoryViewer::on_memoryTableView_clicked(const QModelIndex &index)
 
     // don't show the image if the "active/deactivate" column is clicked
     if (index.column() == 1) return;
+    // don't show the image if the "dump to drive" column is clicked
+    if (index.column() == 2) return;
 
     DataModel *model = dataModelList[cbindex];
     if (model->imageList.isEmpty()) return;   // Not sure this is ever happening
@@ -429,13 +434,12 @@ void MemoryViewer::on_memoryTableView_clicked(const QModelIndex &index)
         connect(iView, &IView::destroyed, this, &MemoryViewer::iViewClosed_received);
         connect(iView, &IView::closed, this, &MemoryViewer::iViewClosed_received);
     }
-//    iView->scene->clear();
     bool sourcecatShown = iView->sourcecatSourcesShown;
     bool refcatShown = iView->refcatSourcesShown;
     iView->clearItems();
-    iView->loadFromRAMlist(index);
+    iView->loadFromRAM(model->imageList[index.row()], index.column());
+//    iView->loadFromRAMlist(index);
     iView->currentId = index.row();
-    // IView needs to know the directory name so that it can overlay catalogs
     iView->setCatalogOverlaysExternally(sourcecatShown, refcatShown);
     iView->redrawSkyCirclesAndCats();
     iView->show();
@@ -447,6 +451,11 @@ void MemoryViewer::iViewClosed_received()
     iViewOpen = false;
 }
 
+void MemoryViewer::activationChangedReceiver()
+{
+    emit activationChanged();
+}
+
 void MemoryViewer::currentlyDisplayedIndex_received(int currentId)
 {
     // Deselect current selection
@@ -475,15 +484,29 @@ void MemoryViewer::on_restorePushButton_clicked()
 
     repopulateRestoreComboBox();
 
-    // header line only changes if we manually resize the viewer
+    // header line only changes if we manually resize the viewer, or:
+    // quickly load the monitor, then the memory viewer again:
+    emit refreshMemoryViewer();
+}
 
-    // TODO: Does not work. perhaps using signal/slot mechanism?
-    //    DataModel *model = dataModelList[ui->datadirComboBox->currentIndex()];
-    //    model->updateheaderLineExternal();
+void MemoryViewer::hideStatusCheckBoxes()
+{
+    ui->procstatusHDUreformatCheckbox->setVisible(false);
+    ui->procstatusProcessscienceCheckbox->setVisible(false);
+    ui->procstatusChopnodCheckbox->setVisible(false);
+    ui->procstatusBackgroundCheckbox->setVisible(false);
+    ui->procstatusCollapseCheckbox->setVisible(false);
+    ui->procstatusStarflatCheckbox->setVisible(false);
+    ui->procstatusSkysubCheckbox->setVisible(false);
 }
 
 void MemoryViewer::showhideStatusCheckBoxes(QString type)
 {
+    hideStatusCheckBoxes();
+    return;
+
+    // Never needed this
+    /*
     Data *data = getDataClassThisModel();
     if (data == nullptr) return;
 
@@ -521,6 +544,7 @@ void MemoryViewer::showhideStatusCheckBoxes(QString type)
         ui->procstatusStarflatCheckbox->setVisible(false);
         ui->procstatusSkysubCheckbox->setVisible(false);
     }
+    */
 }
 
 void MemoryViewer::updateStatusCheckBoxes(Data *data)
@@ -602,6 +626,7 @@ void MemoryViewer::repopulateRestoreComboBox()
     filters << "RAWDATA" << "*_IMAGES";
     QStringList backupdirList = dir.entryList(filters, QDir::Dirs);
     ui->restoreComboBox->clear();
+    // Add the directory only if it is not empty!
     ui->restoreComboBox->addItems(backupdirList);
     ui->restoreComboBox->update();
 }
