@@ -56,6 +56,9 @@ signals:
     void imageSelected(int index);
 
 public slots:
+    void currentlyDisplayedIndexReceived(int currentId);
+    void activationChangedReceiver();
+    void iviewNewImageShownReceiver(int newDataPoint);
 
 private slots:
     void dataPointClicked(QCPAbstractPlottable *plottable, int dataIndex, QMouseEvent *event);
@@ -75,6 +78,9 @@ private slots:
     void on_fwhmunitsComboBox_currentIndexChanged(const QString &arg1);
     void on_actionClose_triggered();
     void on_scienceComboBox_activated(const QString &arg1);
+    void on_chipsLineEdit_editingFinished();
+    void on_raLineEdit_editingFinished();
+    void on_decLineEdit_editingFinished();
 
 private:
     QString mainDir;
@@ -82,11 +88,13 @@ private:
     ProcessingStatus *processingStatus;
     const instrumentDataType *instData;
     QList<Data*> dataList;
+    Data *scienceData;
     Ui::ImageStatistics *ui;
     QString thelidir;
     QString userdir;
     QVector<QList<MyImage*>> myExposureList;
     QList<MyImage*> allMyImages;
+    QList<MyImage*> filteredMyImages;
     QStringList dataName;
     QStringList badStatsList;
     QString scienceDirName;
@@ -119,9 +127,15 @@ private:
     QCPGraph *airmassGraph;
     QCPGraph *rzpGraph;
     QCPGraph *ellipticityGraph;
-    QCPDataSelection selection;    // data points selected by mouse clicks or key presses
-    QCPDataSelection numSelection; // data points selected by manually entered numeric thresholds
+    QCPGraph *skyGraphIview;
+    QCPGraph *seeingGraphIview;
+    QCPGraph *airmassGraphIview;
+    QCPGraph *rzpGraphIview;
+    QCPGraph *ellipticityGraphIview;
+    QCPDataSelection selection;          // data points selected by mouse clicks or key presses
+    QCPDataSelection numSelection;       // data points selected by manually entered numeric thresholds
     QList<QCPGraph*> graphList;
+    QList<QCPGraph*> graphListIview;
     QStringList filteredImageList;
     QList<QLineEdit*> numericThresholdList;
     ImstatsReadme *imstatsReadme;
@@ -140,6 +154,7 @@ private:
     void init();
     bool isImageSelected(MyImage *myImage, const QString &ra, const QString &dec, const QVector<int> &chipID);
     void activateImages();
+    void highlightClickedDataPoint();
 };
 
 #endif // IMAGESTATISTICS_H
