@@ -415,7 +415,7 @@ void Instrument::on_saveConfigPushButton_clicked()
     }
 
     QMessageBox::information( this, "Restart required",
-                              tr("User-defined instrument configurations can be found at the bottom of the instrument selection menu after restarting THELI.") +
+                              tr("User-defined instrument configurations can be found at the bottom of the instrument selection menu after restarting THELI.\n") +
                               tr("If you edited an existing configuration, you must also restart THELI."));
 }
 
@@ -547,8 +547,12 @@ void Instrument::on_loadConfigPushButton_clicked()
 bool Instrument::compareChipNumbers()
 {
     bool comparison = true;
+    int count = 0;
     for (auto &it: geometryNumList) {
+        // skip the first four entries for overscans for NIR detectors
+        if (ui->instrumentTypeComboBox->currentIndex() != 0 && count < 4) continue;
         if (numChips != it->text().toInt()) comparison = false;
+        ++count;
     }
     return comparison;
 }
@@ -656,7 +660,7 @@ void Instrument::on_readRAWgeometryPushButton_clicked()
 {
 
     QString rawFileName = QFileDialog::getOpenFileName(this, tr("Select a CMOS RAW file"), QDir::homePath(),
-                                                       tr("CMOS RAW files (*.CR2 *.ARW *.DNG *.NEF *.cr2 *.arw *.dng *.nef);; Other (*.*)"));
+                                                       tr("CMOS RAW files (*.CR2 *.ARW *.DNG *.NEF *.PEF *.cr2 *.arw *.dng *.nef *.pef);; Other (*.*)"));
 
     // Try opening as RAW
     LibRaw rawProcessor;
