@@ -56,9 +56,9 @@ void Controller::taskInternalHDUreformat()
     progress = 0.;
 
     // Saturation value
-    float satValue = 1.e9;
+    float userSaturationValue = 0.;
     if (!cdw->ui->saturationLineEdit->text().isEmpty()) {
-        satValue = cdw->ui->saturationLineEdit->text().toFloat();
+        userSaturationValue = cdw->ui->saturationLineEdit->text().toFloat();
     }
 
     // Retrieve nonlinearity information (checks internally if available, otherwise returns empty list)
@@ -107,6 +107,7 @@ void Controller::taskInternalHDUreformat()
         Splitter *splitter = new Splitter(*instData, mask, altMask, data, dataType, cdw, mainDirName, dataDir, fileName, &verbosity);
         splitter->headerDictionary = headerDictionary;
         splitter->filterDictionary = filterDictionary;
+        splitter->instrumentDictionary = instrumentDictionary;
         splitter->dummyKeys = dummyKeys;
         splitter->combineOverscan_ptr = combineOverscan_ptr;       // set by MainWindow::updateControllerFunctors()
         splitter->nonlinearityCoefficients = nonlinearityCoefficients;
@@ -115,7 +116,7 @@ void Controller::taskInternalHDUreformat()
         splitter->genericLock = &genericLock;
         splitter->progress = &progress;
         splitter->dateObsIncrementor = &dateObsIncrementor;
-        splitter->saturationValue = satValue;
+        splitter->userSaturationValue = userSaturationValue;
         splitter->compileNumericKeys();
         connect(splitter, &Splitter::messageAvailable, this, &Controller::messageAvailableReceived);
         connect(splitter, &Splitter::critical, this, &Controller::criticalReceived);
@@ -208,7 +209,7 @@ void Controller::uniformMJDOBS(QDir &dir)
                 fits_update_key_dbl(fptr, "MJD-OBS", mjdObsChip1, -13, nullptr, &status);
             }
             fits_close_file(fptr, &status);
-            printCfitsioError("uniformMJDOBS()", status);
+            printCfitsioError(__func__, status);
 
             // Rename image file to THELI standard
             QString dateObsString(dateObsChip1);
@@ -250,6 +251,14 @@ bool Controller::updateDataDirs(Data *data)
         le = getDataTreeLineEdit(data);
     }
 
+    if (instData->name == "PISCO@LCO") {
+        newDirs = d+"_g ";
+        newDirs.append(d+"_r ");
+        newDirs.append(d+"_i ");
+        newDirs.append(d+"_z ");
+        le = getDataTreeLineEdit(data);
+    }
+
     if (le != nullptr) {
         le->clear();
         le->setText(newDirs);
@@ -314,7 +323,7 @@ void Controller::resetAltInstrumentData()
     altInstData.shortName = "";
     altInstData.nameFullPath = "";
     altInstData.obslat = 0.;
-    altInstData.obslong = 0.;
+    altInstData.obslon = 0.;
     altInstData.bayer = "";
     altInstData.type = "OPT";
     altInstData.pixscale = 1.0; // in arcsec
@@ -367,7 +376,7 @@ void Controller::initAltInstrumentData(QString instrumentNameFullPath)
             bayerFound = true;
         }
         if (line.contains("OBSLAT=")) altInstData.obslat = line.split("=")[1].toFloat();
-        if (line.contains("OBSLONG=")) altInstData.obslong = line.split("=")[1].toFloat();
+        if (line.contains("OBSLONG=")) altInstData.obslon = line.split("=")[1].toFloat();
         if (line.contains("PIXSCALE=")) altInstData.pixscale = line.split("=")[1].toFloat();
 //        if (line.contains("GAIN=")) altInstData.gain = line.split("=")[1].toFloat();
 
