@@ -67,7 +67,7 @@ void getBinnedSize(const instrumentDataType *instData, const QVector<QVector<int
 QVector<int> CDmatrixToTransformationMatrix(QVector<double> CD, QString instName)
 {
     if (instName != "WFC@INT" &&
-            instName != "WFC_2x2@INT") rotateCDmatrix(CD, 0.);
+            instName != "WFC_2x2@INT" && instName != "90Prime@BOK2.3m") rotateCDmatrix(CD, 0.);
     double pscale = sqrt(CD[0]*CD[0] + CD[2]*CD[2]);
 
     QVector<int> T;
@@ -77,7 +77,7 @@ QVector<int> CDmatrixToTransformationMatrix(QVector<double> CD, QString instName
     T.push_back(round(CD[3]/pscale));
 
     if (instName != "WFC@INT" &&
-            instName != "WFC_2x2@INT") {
+            instName != "WFC_2x2@INT" && instName != "90Prime@BOK2.3m") {
         // Take out any flips. Only rotations are allowed for binned mosaics
         if (T[0] == -1 && T[3] == 1) T[0] = 1;
         else if (T[0] == 1 && T[3] == -1) T[3] = 1;
@@ -631,7 +631,7 @@ void match2D(const QVector<QVector<double>> vec1, const QVector<QVector<double>>
 
 // Copy magnitudes and mag errors from a {DEC, RA, <MAG>, <MAGERR>} vector to another {DEC, RA, <MAG>, <MAGERR>} vector (matching)
 // <MAG> can be one or more numbers, e.g. 2 ref mags, or several aperture mags
-// tolerance is in [d/data1/TESTDATA/ST10/NGC4651/NGC4651_ALL/coadd_Redeg]
+// tolerance is in [deg]
 void match2D(const QVector<QVector<double>> vec1, QVector<QVector<double>> vec2, QVector<QVector<double>> &matched,
              double tolerance, int &multiple1, int &multiple2, int nthreads)
 {
